interface IColumnHeader {
  Header: string;
  accessor: string | ((row: any) => string);
  Cell?: (row: any) => JSX.Element;
}

type Columns = IColumnHeader[];

export const columnsDataKYC: Columns = [
  {
    Header: "KYC ID",
    accessor: "id",
  },
  {
    Header: "Full Name",
    accessor: "full_name",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Contact Information",
    accessor: "contact_information",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Address",
    accessor: "address",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Meter Number",
    accessor: "meter_no",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Case Consumer No",
    accessor: (row: any) => row.attempt?.case?.consumer_no ?? "N/A",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Case Account No",
    accessor: (row: any) => row.attempt?.case?.contract_account ?? "N/A",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Case Contract No",
    accessor: (row: any) => row.attempt?.case?.contract ?? "N/A",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Additional Meter Requirement",
    accessor: "additional_meter",
    Cell: ({ value }) => (value ? "Yes" : "No"),
  },
  {
    Header: "Premises in Use",
    accessor: "premises_in_use",
    Cell: ({ value }) => (value ? "Yes" : "No"),
  },
  {
    Header: "Meter Exist on Site",
    accessor: "meter_exist_on_site",
    Cell: ({ value }) => (value ? "Yes" : "No"),
  },
  {
    Header: "Premises Type",
    accessor: "premises_type",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Property Type",
    accessor: "property_type",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Meters Installed",
    accessor: "meters_installed",
    Cell: ({ value }) => (value ? "Yes" : "No"),
  },
  {
    Header: "Additional Meter Requirement",
    accessor: "additional_meter_req",
    Cell: ({ value }) => (value ? "Yes" : "No"),
  },
  {
    Header: "Additional Meter Applied",
    accessor: "additional_meter_applied",
    Cell: ({ value }) => (value ? "Yes" : "No"),
  },
  {
    Header: "Latitude",
    accessor: "latitude",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Longitude",
    accessor: "longitude",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Created By",
    accessor: (row: any) => `${row.created_by?.first_name || ""} ${row.created_by?.last_name || ""}`.trim(),
    Cell: ({ value }) => value || "N/A",
  },
  {
    Header: "Created At",
    accessor: "created_at",
    Cell: ({ value }) => (value ? new Date(value).toLocaleDateString() : "N/A"),
  },
];